pub trait Compare<Other>where
Self: View,
Other: View<V = Self::V>,{
// Required method
exec fn compare(&self, other: &Other) -> o : bool;
}Expand description
A helper trait for two different types that can be compared.
pub trait Compare<Other>where
Self: View,
Other: View<V = Self::V>,{
// Required method
exec fn compare(&self, other: &Other) -> o : bool;
}A helper trait for two different types that can be compared.